/* tap_dfilter_dlg.h
 * Header file for display filter dialog used by GTK gui taps
 * Copyright 2003 Lars Roland
 *
 * $Id: tap_dfilter_dlg.h,v 1.3 2004/06/02 22:13:04 ulfl Exp $
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.com>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/** @file
 *  Display filter dialog box used by GTK gui taps.
 */

/**
 * Create the filter dialog box.
 *
 * @param widget parent widget (unused)
 * @param data the dfilter tap dialog
 */
void gtk_tap_dfilter_dlg_cb(GtkWidget *widget, gpointer data);
